==> qabc_1.6.orig.tar.gz: qabc-1.6/qabc_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AbcMainWindow</name>
    <message>
        <location filename="AbcMainWindow.cpp" line="6"/>
        <source>QAbc</source>
        <translation>QAbc</translation>
    </message>
    <message>
        <location filename="AbcMainWindow.cpp" line="12"/>
        <source>Idle</source>
        <translation>Rien à faire</translation>
    </message>
</context>
<context>
    <name>EditTabWidget</name>
    <message>
        <location filename="EditTabWidget.cpp" line="67"/>
        <source>Really close?</source>
        <translation>Fermer vraiment ?</translation>
    </message>
    <message>
        <location filename="EditTabWidget.cpp" line="68"/>
        <source>Current score not saved!
Close this score anyway?</source>
        <translation>La partition courante n&apos;est pas enregistrée !
Fermer cette partition quand-même ?</translation>
    </message>
</context>
<context>
    <name>EditVBoxLayout</name>
    <message>
        <location filename="EditVBoxLayout.cpp" line="23"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="315"/>
        <source>Generating MIDI for playing.</source>
        <translation>Génération du MIDI pour jouer.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="320"/>
        <source>Stopping synthesis.</source>
        <translation>Arrêt de la synthèse.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="331"/>
        <source>Error during MIDI generation.</source>
        <translation>Erreur pendant la génération du MIDI.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="337"/>
        <source>MIDI generation finished.</source>
        <translation>Génération du MIDI terminée.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="351"/>
        <source>Starting synthesis...</source>
        <translation>Démarrage de la synthèse...</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="361"/>
        <source>Synthesis finished.</source>
        <translation>Synthèse terminée.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="376"/>
        <source>Generating score...</source>
        <translation>Génération de la partition...</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="399"/>
        <source>Refresh &amp;view</source>
        <translation>Rafraîchir la &amp;vue</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="404"/>
        <source>Error during score generation.</source>
        <translation>Erreur pendant la génération de la partition.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="408"/>
        <source>Score generated.</source>
        <translation>Patition générée.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="426"/>
        <source>Starting viewer...</source>
        <translation>Démarrage du visualiseur...</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="435"/>
        <source>Viewer closed.</source>
        <translation>Visualiseur fermé.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="442"/>
        <source>&amp;View score</source>
        <translation>&amp;Voir la partition</translation>
    </message>
</context>
<context>
    <name>EditorPrefDialog</name>
    <message>
        <location filename="editorprefdialog.cpp" line="12"/>
        <source>Editor settings</source>
        <translation>Paramètres de l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="18"/>
        <source>Highlight current line</source>
        <translation>Ligne courante en surbrillance</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="29"/>
        <source>Header color</source>
        <translation>Couleur des en-têtes</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="30"/>
        <source>Comment color</source>
        <translation>Couleur des commentaires</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="31"/>
        <source>Extra instruction color</source>
        <translation>Couleur des instructions</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="32"/>
        <source>Measure bar color</source>
        <translation>Couleur des barres de mesure</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="33"/>
        <source>Decoration color</source>
        <translation>Couleur des décorations</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="34"/>
        <source>Guitar chord color</source>
        <translation>Couleur des accords de guitare</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="35"/>
        <source>Lyric color</source>
        <translation>Couleur des paroles</translation>
    </message>
</context>
<context>
    <name>HelpMenu</name>
    <message>
        <location filename="HelpMenu.cpp" line="9"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="11"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="14"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="28"/>
        <location filename="HelpMenu.cpp" line="34"/>
        <source>ABC score editor</source>
        <oldsource>Abc score editor</oldsource>
        <translation>Éditeur de partition ABC</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="28"/>
        <source>Copyright © 2020 Benoît Rouits &lt;brouits@free.fr&gt;</source>
        <translation>Copyright © 2020 Benoît Rouits &lt;brouit@free.fr&gt;</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="28"/>
        <source>
QAbc version </source>
        <translation>
QAbc version </translation>
    </message>
</context>
<context>
    <name>PlayPushButton</name>
    <message>
        <location filename="PlayPushButton.cpp" line="7"/>
        <location filename="PlayPushButton.cpp" line="21"/>
        <source>&amp;Play</source>
        <oldsource>Play</oldsource>
        <translation>Joue&amp;r</translation>
    </message>
    <message>
        <location filename="PlayPushButton.cpp" line="18"/>
        <source>Sto&amp;p</source>
        <translation>A&amp;rrêter</translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="PreferencesMenu.cpp" line="11"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="14"/>
        <source>MIDI Generator</source>
        <translation>Générateur MIDI</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="17"/>
        <source>MIDI Synthesizer</source>
        <translation>Synthétiseur MIDI</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="20"/>
        <source>Score generator</source>
        <translation>Générateur de partition</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="23"/>
        <source>Score viewer</source>
        <oldsource>Viewer</oldsource>
        <translation>Visualiseur de partition</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="26"/>
        <source>Editor settings</source>
        <translation>Paramètres de l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="29"/>
        <source>Reset to defaults</source>
        <translation>Remettre à zéro</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="53"/>
        <location filename="PreferencesMenu.cpp" line="55"/>
        <source>Compiler preference</source>
        <translation>Préférence du compilateur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="53"/>
        <location filename="PreferencesMenu.cpp" line="55"/>
        <source>Compiler:</source>
        <translation>Compilateur :</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="113"/>
        <location filename="PreferencesMenu.cpp" line="115"/>
        <source>PS viewer preference</source>
        <translation>Préférence du visualiseur PS</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="113"/>
        <location filename="PreferencesMenu.cpp" line="115"/>
        <source>PS Viewer:</source>
        <translation>Visualiseur PS :</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="73"/>
        <location filename="PreferencesMenu.cpp" line="75"/>
        <source>Player preference</source>
        <translation>Préférence du joueur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="73"/>
        <location filename="PreferencesMenu.cpp" line="75"/>
        <source>Player:</source>
        <translation>Joueur :</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="93"/>
        <location filename="PreferencesMenu.cpp" line="95"/>
        <source>Synth preference</source>
        <translation>Préférence du synthétiseur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="93"/>
        <location filename="PreferencesMenu.cpp" line="95"/>
        <source>Synth:</source>
        <translation>Synthétiseur :</translation>
    </message>
</context>
<context>
    <name>RunPushButton</name>
    <message>
        <location filename="RunPushButton.cpp" line="6"/>
        <source>&amp;View score</source>
        <oldsource>Generate score</oldsource>
        <translation>&amp;Voir la partition</translation>
    </message>
</context>
<context>
    <name>ScoreMenu</name>
    <message>
        <location filename="ScoreMenu.cpp" line="15"/>
        <source>Score</source>
        <translation>Partition</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="18"/>
        <source>New</source>
        <translation>Nouvelle</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="22"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="26"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="29"/>
        <source>Save as</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="33"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="37"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="63"/>
        <source>Really quit?</source>
        <translation>Quitter vraiment ?</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="65"/>
        <source> score(s) not saved.
Do you want to quit anyway?</source>
        <translation> partition(s) non enregistrée(s).
Voulez-vous quitter quand-même ?</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="85"/>
        <source>Open ABC Score</source>
        <translation>Ouvrir une partition ABC</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="85"/>
        <location filename="ScoreMenu.cpp" line="147"/>
        <source>ABC score (*.abc)</source>
        <translation>Partition ABC (*.abc)</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="118"/>
        <location filename="ScoreMenu.cpp" line="133"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="118"/>
        <source>Could not save an untitled ABC score!</source>
        <translation>Impossible d&apos;enregistrer une partition ABC sans titre !</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="131"/>
        <source>Score saved.</source>
        <translation>Partition enregistrée.</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="147"/>
        <source>Save ABC score</source>
        <translation>Enregistrer la partition ABC</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="133"/>
        <source>Could not save ABC score!</source>
        <translation>Impossible d&apos;enregistrer la partition ABC !</translation>
    </message>
</context>
<context>
    <name>ViewVBoxLayout</name>
    <message>
        <location filename="ViewVBoxLayout.cpp" line="7"/>
        <source>Clear log</source>
        <translation>Nettoyer le log</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="30"/>
        <source>ABC score file to work on.</source>
        <translation>Partition ABC sur laquelle travailler.</translation>
    </message>
</context>
</TS>

==> qabc_1.8.orig.tar.gz: qabc-1.8/qabc_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AbcMainWindow</name>
    <message>
        <location filename="AbcMainWindow.cpp" line="16"/>
        <source>QAbc</source>
        <translation>QAbc</translation>
    </message>
    <message>
        <location filename="AbcMainWindow.cpp" line="22"/>
        <source>Idle</source>
        <translation>Rien à faire</translation>
    </message>
</context>
<context>
    <name>EditTabWidget</name>
    <message>
        <location filename="EditTabWidget.cpp" line="77"/>
        <source>Really close?</source>
        <translation>Fermer vraiment ?</translation>
    </message>
    <message>
        <location filename="EditTabWidget.cpp" line="78"/>
        <source>Current score not saved!
Close this score anyway?</source>
        <translation>La partition courante n&apos;est pas enregistrée !
Fermer cette partition quand-même ?</translation>
    </message>
</context>
<context>
    <name>EditVBoxLayout</name>
    <message>
        <location filename="EditVBoxLayout.cpp" line="33"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="176"/>
        <source>Failed to start program: </source>
        <translation>Impossible de démarrer le programme : </translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="177"/>
        <source>Please check settings.</source>
        <translation>Veuillez vérifier les paramètres.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="358"/>
        <source>Generating MIDI for playing.</source>
        <translation>Génération du MIDI pour jouer.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="363"/>
        <source>Stopping synthesis.</source>
        <translation>Arrêt de la synthèse.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="374"/>
        <source>Error during MIDI generation.</source>
        <translation>Erreur pendant la génération du MIDI.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="380"/>
        <source>MIDI generation finished.</source>
        <translation>Génération du MIDI terminée.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="394"/>
        <source>Starting synthesis...</source>
        <translation>Démarrage de la synthèse...</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="404"/>
        <source>Synthesis finished.</source>
        <translation>Synthèse terminée.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="421"/>
        <source>Generating score...</source>
        <translation>Génération de la partition...</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="444"/>
        <source>Refresh &amp;view</source>
        <translation>Rafraîchir la &amp;vue</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="449"/>
        <source>Error during score generation.</source>
        <translation>Erreur pendant la génération de la partition.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="453"/>
        <source>Score generated.</source>
        <translation>Patition générée.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="471"/>
        <source>Starting viewer...</source>
        <translation>Démarrage du visualiseur...</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="480"/>
        <source>Viewer closed.</source>
        <translation>Visualiseur fermé.</translation>
    </message>
    <message>
        <location filename="EditVBoxLayout.cpp" line="193"/>
        <location filename="EditVBoxLayout.cpp" line="487"/>
        <source>&amp;View score</source>
        <translation>&amp;Voir la partition</translation>
    </message>
</context>
<context>
    <name>EditorPrefDialog</name>
    <message>
        <location filename="editorprefdialog.cpp" line="22"/>
        <source>Editor settings</source>
        <translation>Paramètres de l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="28"/>
        <source>Highlight current line</source>
        <translation>Ligne courante en surbrillance</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="39"/>
        <source>Header color</source>
        <translation>Couleur d&apos;en-tête</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="40"/>
        <source>Comment color</source>
        <translation>Couleur de commentaire</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="41"/>
        <source>Extra instruction color</source>
        <translation>Couleur d&apos; instruction</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="42"/>
        <source>Measure bar color</source>
        <translation>Couleur de barre de mesure</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="43"/>
        <source>Decoration color</source>
        <translation>Couleur de décoration</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="44"/>
        <source>Guitar chord color</source>
        <translation>Couleur d&apos; accord de guitare</translation>
    </message>
    <message>
        <location filename="editorprefdialog.cpp" line="45"/>
        <source>Lyric color</source>
        <translation>Couleur de parole</translation>
    </message>
</context>
<context>
    <name>HelpMenu</name>
    <message>
        <location filename="HelpMenu.cpp" line="19"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="21"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="24"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="38"/>
        <location filename="HelpMenu.cpp" line="44"/>
        <source>ABC score editor</source>
        <oldsource>Abc score editor</oldsource>
        <translation>Éditeur de partition ABC</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="38"/>
        <source>Copyright © 2020 Benoît Rouits &lt;brouits@free.fr&gt;</source>
        <translation>Copyright © 2020 Benoît Rouits &lt;brouit@free.fr&gt;</translation>
    </message>
    <message>
        <location filename="HelpMenu.cpp" line="38"/>
        <source>
QAbc version </source>
        <translation>
QAbc version </translation>
    </message>
</context>
<context>
    <name>PlayPushButton</name>
    <message>
        <location filename="PlayPushButton.cpp" line="17"/>
        <location filename="PlayPushButton.cpp" line="31"/>
        <source>&amp;Play</source>
        <oldsource>Play</oldsource>
        <translation>Joue&amp;r</translation>
    </message>
    <message>
        <location filename="PlayPushButton.cpp" line="28"/>
        <source>Sto&amp;p</source>
        <translation>A&amp;rrêter</translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <location filename="PreferencesMenu.cpp" line="21"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="24"/>
        <source>MIDI Generator</source>
        <translation>Générateur MIDI</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="27"/>
        <source>MIDI Synthesizer</source>
        <translation>Synthétiseur MIDI</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="30"/>
        <source>Score generator</source>
        <translation>Générateur de partition</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="33"/>
        <source>Score viewer</source>
        <oldsource>Viewer</oldsource>
        <translation>Visualiseur de partition</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="36"/>
        <source>Editor settings</source>
        <translation>Paramètres de l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="39"/>
        <source>Reset to defaults</source>
        <translation>Remettre à zéro</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="63"/>
        <location filename="PreferencesMenu.cpp" line="65"/>
        <source>Compiler preference</source>
        <translation>Préférence du compilateur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="63"/>
        <location filename="PreferencesMenu.cpp" line="65"/>
        <source>Compiler:</source>
        <translation>Compilateur :</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="123"/>
        <location filename="PreferencesMenu.cpp" line="125"/>
        <source>PS viewer preference</source>
        <translation>Préférence du visualiseur PS</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="123"/>
        <location filename="PreferencesMenu.cpp" line="125"/>
        <source>PS Viewer:</source>
        <translation>Visualiseur PS :</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="83"/>
        <location filename="PreferencesMenu.cpp" line="85"/>
        <source>Player preference</source>
        <translation>Préférence du joueur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="83"/>
        <location filename="PreferencesMenu.cpp" line="85"/>
        <source>Player:</source>
        <translation>Joueur :</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="103"/>
        <location filename="PreferencesMenu.cpp" line="105"/>
        <source>Synth preference</source>
        <translation>Préférence du synthétiseur</translation>
    </message>
    <message>
        <location filename="PreferencesMenu.cpp" line="103"/>
        <location filename="PreferencesMenu.cpp" line="105"/>
        <source>Synth:</source>
        <translation>Synthétiseur :</translation>
    </message>
</context>
<context>
    <name>RunPushButton</name>
    <message>
        <location filename="RunPushButton.cpp" line="16"/>
        <source>&amp;View score</source>
        <oldsource>Generate score</oldsource>
        <translation>&amp;Voir la partition</translation>
    </message>
</context>
<context>
    <name>ScoreMenu</name>
    <message>
        <location filename="ScoreMenu.cpp" line="25"/>
        <source>Score</source>
        <translation>Partition</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="28"/>
        <source>New</source>
        <translation>Nouvelle</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="32"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="36"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="43"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="47"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="73"/>
        <source>Really quit?</source>
        <translation>Quitter vraiment ?</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="75"/>
        <source> score(s) not saved.
Do you want to quit anyway?</source>
        <translation> partition(s) non enregistrée(s).
Voulez-vous quitter quand-même ?</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="95"/>
        <source>Open ABC Score</source>
        <translation>Ouvrir une partition ABC</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="95"/>
        <location filename="ScoreMenu.cpp" line="157"/>
        <source>ABC score (*.abc)</source>
        <translation>Partition ABC (*.abc)</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="128"/>
        <location filename="ScoreMenu.cpp" line="143"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="128"/>
        <source>Could not save an untitled ABC score!</source>
        <translation>Impossible d&apos;enregistrer une partition ABC sans titre !</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="141"/>
        <source>Score saved.</source>
        <translation>Partition enregistrée.</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="157"/>
        <source>Save ABC score</source>
        <translation>Enregistrer la partition ABC</translation>
    </message>
    <message>
        <location filename="ScoreMenu.cpp" line="143"/>
        <source>Could not save ABC score!</source>
        <translation>Impossible d&apos;enregistrer la partition ABC !</translation>
    </message>
</context>
<context>
    <name>ViewVBoxLayout</name>
    <message>
        <location filename="ViewVBoxLayout.cpp" line="17"/>
        <source>Clear log</source>
        <translation>Nettoyer le log</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="40"/>
        <source>ABC score file to work on.</source>
        <translation>Partition ABC sur laquelle travailler.</translation>
    </message>
</context>
</TS>
